<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\MAN\Services\RelatorioService;

use Zeedhi\Framework\Controller\CrudWithParameterBag;

class RelSetorProducaoKDS extends CrudWithParameterBag {
    const REL_SETOR_PRODUCAO_KDS = 'orm00021_relSetorProducaoKDS';
	
	protected $parameterBagColumns = array('NRORG', 'CDFILIAL', 'TCDFILIAL', 'CDSETOR', 'TCDSETOR', 'CDPRODUTO', 'TCDPRODUTO', 'DTINIT', 'DTFIM');
	protected $dataSourceName = self::REL_SETOR_PRODUCAO_KDS;
	protected $relatorioService;
	
	public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, RelatorioService $relatorioService) {
    	$this->relatorioService = $relatorioService;
        parent::__construct($dataSourceManager, $parameterBag);
    }
    
	public function find(DTO\Request\Filter $request, DTO\Response $response) {
		$conditions = $this->relatorioService->getParamsAsArray($request);
		
		unset($conditions['NMFILIAL']);
		unset($conditions['NMPRODUTO']);
		
		$likeableConditions = $this->relatorioService->getLikeConditions($request);
		
		foreach ($likeableConditions as $condition) {
			if(array_key_exists($condition['columnName'], $conditions)) {
				 unset($conditions[$condition['columnName']]);
			}
		}
		
		$conditions = $this->relatorioService->addParams($conditions, 'CDFILIAL');
		$conditions = $this->relatorioService->addParams($conditions, 'CDSETOR');
		$conditions = $this->relatorioService->addParams($conditions, 'CDPRODUTO');
		$this->relatorioService->setIntervalAsDTINIandDTFIM($conditions, 'DTENTRVENDA', 'DTINIT', 'DTFIM');

		$request = $this->relatorioService->createNewZeedhiFilterRequestObject($request, $this->dataSourceName, $conditions); 
		
		
		// Adds to this new Request, all the likeable conditions
		foreach ($likeableConditions as $condition) {
			$request->getFilterCriteria()->addCondition($condition['columnName'], "MAPPED_LIKE_ALL", $condition['value']);
		}
			
		parent::find($request, $response);
	}
}